"""This module contains (predefined) relations."""

from visions.relations.relations import (
    IdentityRelation,
    InferenceRelation,
    TypeRelation,
)

__all__ = [
    "IdentityRelation",
    "InferenceRelation",
    "TypeRelation",
]
